@@ -10,6 +10,7 @@ from .exceptions import (
     ModelNotFoundError,
     VersionedModelError,
 )
+from .migration_hooks import MetricsHook, MigrationHook
 from .migration_testing import (
     MigrationTestCase,
     MigrationTestCases,
@@ -19,8 +20,10 @@ from .migration_testing import (
 from .model_diff import ModelDiff
 from .model_manager import ModelManager
 from .model_version import ModelVersion
+from .schema_config import SchemaConfig
 from .types import (
     JsonSchema,
+    JsonSchemaMode,
     MigrationFunc,
     ModelData,
     NestedModelInfo,
@@ -29,8 +32,11 @@ from .types import (
 __all__ = [
     "InvalidVersionError",
     "JsonSchema",
+    "JsonSchemaMode",
+    "MetricsHook",
     "MigrationError",
     "MigrationFunc",
+    "MigrationHook",
     "MigrationManager",
     "MigrationTestCase",
     "MigrationTestCases",
@@ -43,6 +49,7 @@ __all__ = [
     "ModelVersion",
     "NestedModelInfo",
     "Registry",
+    "SchemaConfig",
     "SchemaManager",
     "VersionedModelError",
     "__version__",
