@@ -1,4 +1,4 @@
-"""Model manager."""
+"""ModelManager class."""
 
 from collections.abc import Callable, Iterable
 from concurrent.futures import ProcessPoolExecutor, ThreadPoolExecutor
@@ -6,11 +6,13 @@ from pathlib import Path
 from typing import Any, Self
 
 from pydantic import BaseModel
+from pydantic.json_schema import GenerateJsonSchema
 
 from ._migration_manager import MigrationManager
 from ._registry import Registry
 from ._schema_manager import SchemaManager
 from .exceptions import MigrationError, ModelNotFoundError
+from .migration_hooks import MigrationHook
 from .migration_testing import (
     MigrationTestCase,
     MigrationTestCases,
@@ -19,6 +21,7 @@ from .migration_testing import (
 )
 from .model_diff import ModelDiff
 from .model_version import ModelVersion
+from .schema_config import SchemaConfig
 from .types import (
     DecoratedBaseModel,
     JsonSchema,
@@ -26,81 +29,153 @@ from .types import (
     MigrationFunc,
     ModelData,
     NestedModelInfo,
+    SchemaTransformer,
 )
 
 
 class ModelManager:
-    """High-level interface for versioned model management.
+    """High-level interface for versioned model management and schema generation.
 
     ModelManager provides a unified API for managing schema evolution across different
     versions of Pydantic models. It handles model registration, automatic migration
-    between versions, schema generation, and batch processing operations.
+    between versions, customizable schema generation, and batch processing operations.
 
-    Attributes:
-        registry: Registry instance managing all registered model versions.
-        migration_manager: MigrationManager instance handling migration logic and paths.
-        schema_manager: SchemaManager instance for JSON schema generation and export.
+    Example:
+        **Basic Usage**:
 
-    Basic Usage:
-        >>> manager = ModelManager()
-        >>>
-        >>> # Register model versions
-        >>> @manager.model("User", "1.0.0")
-        ... class UserV1(BaseModel):
-        ...     name: str
-        >>>
-        >>> @manager.model("User", "2.0.0")
-        ... class UserV2(BaseModel):
-        ...     name: str
-        ...     email: str
-        >>>
-        >>> # Define migration between versions
-        >>> @manager.migration("User", "1.0.0", "2.0.0")
-        ... def migrate(data: ModelData) -> ModelData:
-        ...     return {**data, "email": "unknown@example.com"}
-        >>>
-        >>> # Migrate legacy data
-        >>> old_data = {"name": "Alice"}
-        >>> user = manager.migrate(old_data, "User", "1.0.0", "2.0.0")
-        >>> # Result: UserV2(name="Alice", email="unknown@example.com")
+        ```python
+        from pyrmute import ModelManager, ModelData
 
-    Advanced Features:
-        >>> # Batch migration with parallel processing
-        >>> users = manager.migrate_batch(
-        ...     legacy_users, "User", "1.0.0", "2.0.0",
-        ...     parallel=True, max_workers=4
-        ... )
-        >>>
-        >>> # Stream large datasets efficiently
-        >>> for user in manager.migrate_batch_streaming(large_dataset, "User", "1.0.0", "2.0.0"):
-        ...     save_to_database(user)
-        >>>
-        >>> # Compare versions and export schemas
-        >>> diff = manager.diff("User", "1.0.0", "2.0.0")
-        >>> print(diff.to_markdown())
-        >>> manager.dump_schemas("schemas/", separate_definitions=True)
-        >>>
-        >>> # Test migrations with validation
-        >>> results = manager.test_migration(
-        ...     "User", "1.0.0", "2.0.0",
-        ...     test_cases=[
-        ...         ({"name": "Alice"}, {"name": "Alice", "email": "unknown@example.com"})
-        ...     ]
-        ... )
-        >>> results.assert_all_passed()
-    """  # noqa: E501
+        manager = ModelManager()
 
-    def __init__(self: Self) -> None:
-        """Initialize the versioned model manager."""
+        # Register model versions
+        @manager.model("User", "1.0.0")
+        class UserV1(BaseModel):
+            name: str
+
+        @manager.model("User", "2.0.0")
+        class UserV2(BaseModel):
+            name: str
+            email: str
+
+        # Define migration between versions
+        @manager.migration("User", "1.0.0", "2.0.0")
+        def migrate(data: ModelData) -> ModelData:
+            return {**data, "email": "unknown@example.com"}
+
+        # Migrate legacy data
+        old_data = {"name": "Alice"}
+        user = manager.migrate(old_data, "User", "1.0.0", "2.0.0")
+        # Result: UserV2(name="Alice", email="unknown@example.com")
+        ```
+
+        **Custom Schema Generation**:
+
+        ```python
+        from pydantic.json_schema import GenerateJsonSchema
+
+        class CustomSchemaGenerator(GenerateJsonSchema):
+            '''Add custom metadata to all schemas.'''
+            def generate(
+                self,
+                schema: Mapping[str, Any],
+                mode: JsonSchemaMode = "validation"
+            ) -> JsonSchema:
+                json_schema = super().generate(schema, mode=mode)
+                json_schema["x-company"] = "Acme"
+                json_schema["$schema"] = self.schema_dialect
+                return json_schema
+
+        # Set at manager level (applies to all schemas)
+        manager = ModelManager(
+            default_schema_config=SchemaConfig(
+                schema_generator=CustomSchemaGenerator,
+                mode="validation",
+                by_alias=True
+            )
+        )
+
+        @manager.model("User", "1.0.0")
+        class User(BaseModel):
+            name: str = Field(title="Full Name")
+            email: str
+
+        # Get schema with default config
+        schema = manager.get_schema("User", "1.0.0")
+        # Will include x-company: "Acme"
+        ```
+
+        **Advanced Features**:
+
+        ```python
+        # Batch migration with parallel processing
+        users = manager.migrate_batch(
+            legacy_users, "User", "1.0.0", "2.0.0",
+            parallel=True, max_workers=4
+        )
+
+        # Stream large datasets efficiently
+        for user in manager.migrate_batch_streaming(
+            large_dataset, "User", "1.0.0", "2.0.0"
+         ):
+            save_to_database(user)
+
+        # Compare versions and export schemas
+        diff = manager.diff("User", "1.0.0", "2.0.0")
+        print(diff.to_markdown())
+        manager.dump_schemas("schemas/", separate_definitions=True)
+
+        # Test migrations with validation
+        results = manager.test_migration(
+            "User", "1.0.0", "2.0.0",
+            test_cases=[
+                (
+                     {"name": "Alice"},
+                     {"name": "Alice", "email": "unknown@example.com"}
+                )
+            ]
+        )
+        results.assert_all_passed()
+        ```
+
+        **Schema Transformers**:
+
+        ```python
+        manager = ModelManager()
+
+        @manager.model("Product", "1.0.0")
+        class Product(BaseModel):
+            name: str
+            price: float
+
+        # Add transformer for specific model
+        @manager.schema_transformer("Product", "1.0.0")
+        def add_examples(schema: JsonSchema) -> JsonSchema:
+            schema["examples"] = [{"name": "Widget", "price": 9.99}]
+            return schema
+
+        schema = manager.get_schema("Product", "1.0.0")
+        # Will include examples
+        ```
+    """
+
+    def __init__(self: Self, default_schema_config: SchemaConfig | None = None) -> None:
+        """Initialize the versioned model manager.
+
+        Args:
+            default_schema_config: Default configuration for schema generation
+                applied to all schema operations unless overridden.
+        """
         self._registry = Registry()
         self._migration_manager = MigrationManager(self._registry)
-        self._schema_manager = SchemaManager(self._registry)
+        self._schema_manager = SchemaManager(
+            self._registry, default_config=default_schema_config
+        )
 
     def model(
         self: Self,
         name: str,
         version: str | ModelVersion,
-        schema_generator: JsonSchemaGenerator | None = None,
         enable_ref: bool = False,
         backward_compatible: bool = False,
     ) -> Callable[[type[DecoratedBaseModel]], type[DecoratedBaseModel]]:
@@ -109,7 +184,6 @@ class ModelManager:
         Args:
             name: Name of the model.
             version: Semantic version.
-            schema_generator: Optional custom schema generator.
             enable_ref: If True, this model can be referenced via $ref in separate
                 schema files. If False, it will always be inlined.
             backward_compatible: If True, this model does not need a migration function
@@ -120,19 +194,19 @@ class ModelManager:
             Decorator function for model class.
 
         Example:
-            >>> # Model that will be inlined (default)
-            >>> @manager.model("Address", "1.0.0")
-            ... class AddressV1(BaseModel):
-            ...     street: str
-            >>>
-            >>> # Model that can be a separate schema with $ref
-            >>> @manager.model("City", "1.0.0", enable_ref=True)
-            ... class CityV1(BaseModel):
-            ...     city: City
+            ```python
+            # Model that will be inlined (default)
+            @manager.model("Address", "1.0.0")
+            class AddressV1(BaseModel):
+                street: str
+
+            # Model that can be a separate schema with $ref
+            @manager.model("City", "1.0.0", enable_ref=True)
+            class CityV1(BaseModel):
+                city: City
+            ```
         """
-        return self._registry.register(
-            name, version, schema_generator, enable_ref, backward_compatible
-        )
+        return self._registry.register(name, version, enable_ref, backward_compatible)
 
     def migration(
         self: Self,
@@ -154,6 +228,50 @@ class ModelManager:
             name, from_version, to_version
         )
 
+    def add_hook(self: Self, hook: MigrationHook) -> None:
+        """Register a migration hook for observability/logging.
+
+        Args:
+            hook: Migration hook instance to register.
+
+        Example:
+            ```python
+            from pyrmute import MetricsHook, MigrationHook
+            import logging
+
+            # Use built-in metrics hook
+            metrics = MetricsHook()
+            manager.add_hook(metrics)
+
+            # Add custom logging hook
+            class LoggingHook(MigrationHook):
+                def before_migrate(
+                    self,
+                    name: str,
+                    from_version: ModelVersion,
+                    to_version: ModelVersion,
+                    data: Mapping[str, Any],
+                ) -> None:
+                    logging.info(f"Starting migration: {name}")
+                    return data
+
+            manager.add_hook(LoggingHook())
+            ```
+        """
+        self._migration_manager.add_hook(hook)
+
+    def remove_hook(self: Self, hook: MigrationHook) -> None:
+        """Remove a previously registered hook.
+
+        Args:
+            hook: Migration hook instance to remove.
+        """
+        self._migration_manager.remove_hook(hook)
+
+    def clear_hooks(self: Self) -> None:
+        """Remove all registered hooks."""
+        self._migration_manager.clear_hooks()
+
     def get(self: Self, name: str, version: str | ModelVersion) -> type[BaseModel]:
         """Get a model by name and version.
 
@@ -194,10 +312,12 @@ class ModelManager:
             True if a migration path exists, False otherwise.
 
         Example:
-            >>> if manager.has_migration_path("User", "1.0.0", "3.0.0"):
-            ...     users = manager.migrate_batch(old_users, "User", "1.0.0", "3.0.0")
-            ... else:
-            ...     logger.error("Cannot migrate users to v3.0.0")
+            ```python
+            if manager.has_migration_path("User", "1.0.0", "3.0.0"):
+                users = manager.migrate_batch(old_users, "User", "1.0.0", "3.0.0")
+            else:
+                logger.error("Cannot migrate users to v3.0.0")
+            ```
         """
         from_ver = (
             ModelVersion.parse(from_version)
@@ -235,12 +355,14 @@ class ModelManager:
             True if data is valid for the model version, False otherwise.
 
         Example:
-            >>> data = {"name": "Alice"}
-            >>> is_valid = manager.validate_data(data, "User", "1.0.0")
-            >>> # Returns: True
-            >>>
-            >>> is_valid = manager.validate_data(data, "User", "2.0.0")
-            >>> # Returns: False, missing required field 'email'
+            ```python
+            data = {"name": "Alice"}
+            is_valid = manager.validate_data(data, "User", "1.0.0")
+            # Returns: True
+
+            is_valid = manager.validate_data(data, "User", "2.0.0")
+            # Returns: False, missing required field 'email'
+            ```
         """
         try:
             model = self.get(name, version)
@@ -271,6 +393,41 @@ class ModelManager:
         target_model = self.get(name, to_version)
         return target_model.model_validate(migrated_data)
 
+    def migrate_as(
+        self: Self,
+        data: ModelData,
+        name: str,
+        from_version: str | ModelVersion,
+        to_version: str | ModelVersion,
+        target_type: type[DecoratedBaseModel],
+    ) -> DecoratedBaseModel:
+        """Migrate data between versions with type safety.
+
+        This is a type-safe variant of migrate() that returns a specific model type when
+        you provide the target type explicitly.
+
+        Args:
+            data: Data dictionary to migrate.
+            name: Name of the model.
+            from_version: Source version.
+            to_version: Target version.
+            target_type: The expected model class type.
+
+        Returns:
+            Migrated model instance of the specified type.
+
+        Example:
+            ```python
+            old_data = {"name": "Alice"}
+            user: UserV2 = manager.migrate_as(
+                old_data, "User", "1.0.0", "2.0.0", UserV2
+            )
+            # Type checker knows user is UserV2, not just BaseModel
+            ```
+        """
+        migrated_data = self.migrate_data(data, name, from_version, to_version)
+        return target_type.model_validate(migrated_data)
+
     def migrate_data(
         self: Self,
         data: ModelData,
@@ -309,27 +466,12 @@ class ModelManager:
             from_version: Source version.
             to_version: Target version.
             parallel: If True, use parallel processing.
-            max_workers: Maximum number of workers for parallel processing.  Defaults to
-                None (uses executor default).
+            max_workers: Maximum number of workers for parallel processing.
             use_processes: If True, use ProcessPoolExecutor instead of
-                ThreadPoolExecutor. Useful for CPU-intensive migrations.
+                ThreadPoolExecutor.
 
         Returns:
             List of migrated BaseModel instances.
-
-        Example:
-            >>> legacy_users = [
-            ...     {"name": "Alice"},
-            ...     {"name": "Bob"},
-            ...     {"name": "Charlie"}
-            ... ]
-            >>> users = manager.migrate_batch(
-            ...     legacy_users,
-            ...     "User",
-            ...     from_version="1.0.0",
-            ...     to_version="3.0.0",
-            ...     parallel=True
-            ... )
         """
         data_list = list(data_list)
 
@@ -349,6 +491,66 @@ class ModelManager:
             ]
             return [future.result() for future in futures]
 
+    def migrate_batch_as(  # noqa: PLR0913
+        self: Self,
+        data_list: Iterable[ModelData],
+        name: str,
+        from_version: str | ModelVersion,
+        to_version: str | ModelVersion,
+        target_type: type[DecoratedBaseModel],
+        parallel: bool = False,
+        max_workers: int | None = None,
+        use_processes: bool = False,
+    ) -> list[DecoratedBaseModel]:
+        """Migrate multiple data items between versions with type safety.
+
+        This is a type-safe variant of migrate_batch() that returns a specific model
+        type when you provide the target type explicitly.
+
+        Args:
+            data_list: Iterable of data dictionaries to migrate.
+            name: Name of the model.
+            from_version: Source version.
+            to_version: Target version.
+            target_type: The expected model class type.
+            parallel: If True, use parallel processing.
+            max_workers: Maximum number of workers for parallel processing.
+            use_processes: If True, use ProcessPoolExecutor instead of
+                ThreadPoolExecutor.
+
+        Returns:
+            List of migrated model instances of the specified type.
+
+        Example:
+            ```python
+            old_users = [{"name": "Alice"}, {"name": "Bob"}]
+            users: list[UserV2] = manager.migrate_batch_as(
+                old_users, "User", "1.0.0", "2.0.0", UserV2,
+                parallel=True, max_workers=4
+            )
+            ```
+        """
+        data_list = list(data_list)
+
+        if not data_list:
+            return []
+
+        if not parallel:
+            return [
+                self.migrate_as(item, name, from_version, to_version, target_type)
+                for item in data_list
+            ]
+
+        executor_class = ProcessPoolExecutor if use_processes else ThreadPoolExecutor
+        with executor_class(max_workers=max_workers) as executor:
+            futures = [
+                executor.submit(
+                    self.migrate_as, item, name, from_version, to_version, target_type
+                )
+                for item in data_list
+            ]
+            return [future.result() for future in futures]
+
     def migrate_batch_data(  # noqa: PLR0913
         self: Self,
         data_list: Iterable[ModelData],
@@ -372,15 +574,6 @@ class ModelManager:
 
         Returns:
             List of raw migrated dictionaries.
-
-        Example:
-            >>> legacy_data = [{"name": "Alice"}, {"name": "Bob"}]
-            >>> migrated_data = manager.migrate_batch_data(
-            ...     legacy_data,
-            ...     "User",
-            ...     from_version="1.0.0",
-            ...     to_version="2.0.0"
-            ... )
         """
         data_list = list(data_list)
 
@@ -411,9 +604,6 @@ class ModelManager:
     ) -> Iterable[BaseModel]:
         """Migrate data in chunks, yielding results as they complete.
 
-        Useful for large datasets where you want to start processing results before all
-        migrations complete.
-
         Args:
             data_list: Iterable of data dictionaries to migrate.
             name: Name of the model.
@@ -423,17 +613,6 @@ class ModelManager:
 
         Yields:
             Migrated BaseModel instances.
-
-        Example:
-            >>> legacy_users = load_large_dataset()
-            >>> for user in manager.migrate_batch_streaming(
-            ...     legacy_users,
-            ...     "User",
-            ...     from_version="1.0.0",
-            ...     to_version="3.0.0"
-            ... ):
-            ...     # Process each user as it's migrated
-            ...     save_to_database(user)
         """
         chunk = []
 
@@ -447,6 +626,55 @@ class ModelManager:
         if chunk:
             yield from self.migrate_batch(chunk, name, from_version, to_version)
 
+    def migrate_batch_streaming_as(  # noqa: PLR0913
+        self: Self,
+        data_list: Iterable[ModelData],
+        name: str,
+        from_version: str | ModelVersion,
+        to_version: str | ModelVersion,
+        target_type: type[DecoratedBaseModel],
+        chunk_size: int = 100,
+    ) -> Iterable[DecoratedBaseModel]:
+        """Migrate data in chunks with type safety, yielding results as they complete.
+
+        This is a type-safe variant of migrate_batch_streaming() that returns a specific
+        model type when you provide the target type explicitly.
+
+        Args:
+            data_list: Iterable of data dictionaries to migrate.
+            name: Name of the model.
+            from_version: Source version.
+            to_version: Target version.
+            target_type: The expected model class type.
+            chunk_size: Number of items to process in each chunk.
+
+        Yields:
+            Migrated model instances of the specified type.
+
+        Example:
+            ```python
+            for user in manager.migrate_batch_streaming_as(
+                large_dataset, "User", "1.0.0", "2.0.0", UserV2
+            ):
+                save_to_database(user)  # user is typed as UserV2
+            ```
+        """
+        chunk = []
+
+        for item in data_list:
+            chunk.append(item)
+
+            if len(chunk) >= chunk_size:
+                yield from self.migrate_batch_as(
+                    chunk, name, from_version, to_version, target_type
+                )
+                chunk = []
+
+        if chunk:
+            yield from self.migrate_batch_as(
+                chunk, name, from_version, to_version, target_type
+            )
+
     def migrate_batch_data_streaming(
         self: Self,
         data_list: Iterable[ModelData],
@@ -457,9 +685,6 @@ class ModelManager:
     ) -> Iterable[ModelData]:
         """Migrate data in chunks, yielding raw dictionaries as they complete.
 
-        Useful for large datasets where you want to start processing results before all
-        migrations complete, without the validation overhead.
-
         Args:
             data_list: Iterable of data dictionaries to migrate.
             name: Name of the model.
@@ -469,17 +694,6 @@ class ModelManager:
 
         Yields:
             Raw migrated dictionaries.
-
-        Example:
-            >>> legacy_data = load_large_dataset()
-            >>> for data in manager.migrate_batch_data_streaming(
-            ...     legacy_data,
-            ...     "User",
-            ...     from_version="1.0.0",
-            ...     to_version="3.0.0"
-            ... ):
-            ...     # Process raw data as it's migrated
-            ...     bulk_insert_to_database(data)
         """
         chunk = []
 
@@ -503,9 +717,6 @@ class ModelManager:
     ) -> ModelDiff:
         """Get a detailed diff between two model versions.
 
-        Compares field names, types, requirements, and default values to provide a
-        comprehensive view of what changed between versions.
-
         Args:
             name: Name of the model.
             from_version: Source version.
@@ -513,12 +724,6 @@ class ModelManager:
 
         Returns:
             ModelDiff with detailed change information.
-
-        Example:
-            >>> diff = manager.diff("User", "1.0.0", "2.0.0")
-            >>> print(diff.to_markdown())
-            >>> print(f"Added: {diff.added_fields}")
-            >>> print(f"Removed: {diff.removed_fields}")
         """
         from_ver_str = str(
             ModelVersion.parse(from_version)
@@ -542,10 +747,150 @@ class ModelManager:
             to_version=to_ver_str,
         )
 
+    def set_default_schema_generator(
+        self: Self, generator: JsonSchemaGenerator | type[GenerateJsonSchema]
+    ) -> None:
+        """Set the default schema generator for all schemas.
+
+        This is a convenience method that updates the default schema configuration.
+
+        Args:
+            generator: Custom schema generator - either a callable or GenerateJsonSchema
+                class.
+
+        Example:
+            **Class**:
+
+            ```python
+            from pydantic.json_schema import GenerateJsonSchema
+
+
+            class MyGenerator(GenerateJsonSchema):
+                def generate(
+                    self,
+                    schema: Mapping[str, Any],
+                    mode: JsonSchemaMode = "validation"
+                ) -> JsonSchema:
+                    json_schema = super().generate(schema, mode=mode)
+                    json_schema["x-custom"] = True
+                    json_schema["$schema"] = self.schema_dialect
+                    return json_schema
+
+            manager = ModelManager()
+            manager.set_default_schema_generator(MyGenerator)
+
+            # All subsequent schema calls will use MyGenerator
+            schema = manager.get_schema("User", "1.0.0")
+            ```
+
+            **Callable**:
+
+            ```python
+            def my_generator(model: type[BaseModel]) -> JsonSchema:
+                schema = model.model_json_schema()
+                schema["x-custom"] = True
+                return schema
+
+            manager = ModelManager()
+            manager.set_default_schema_generator(my_generator)
+            ```
+        """
+        self._schema_manager.set_default_schema_generator(generator)
+
+    def schema_transformer(
+        self: Self,
+        name: str,
+        version: str | ModelVersion,
+    ) -> Callable[[SchemaTransformer], SchemaTransformer]:
+        """Decorator to register a schema transformer for a model version.
+
+        Transformers are simple functions that modify a schema after generation.
+        They're useful for model-specific customizations that don't require deep
+        integration with Pydantic's generation process.
+
+        Args:
+            name: Name of the model.
+            version: Model version.
+
+        Returns:
+            Decorator function.
+
+        Example:
+            ```python
+            @manager.schema_transformer("User", "1.0.0")
+            def add_auth_metadata(schema: JsonSchema) -> JsonSchema:
+                schema["x-requires-auth"] = True
+                schema["x-auth-level"] = 'admin'
+                return schema
+
+            @manager.schema_transformer("Product", "2.0.0")
+            def add_product_examples(schema: JsonSchema) -> JsonSchema:
+                schema["examples"] = [
+                    {"name": "Widget", "price": 9.99},
+                    {"name": "Gadget", "price": 19.99}
+                ]
+                return schema
+            ```
+        """
+
+        def decorator(func: SchemaTransformer) -> SchemaTransformer:
+            self._schema_manager.register_transformer(name, version, func)
+            return func
+
+        return decorator
+
+    def get_schema_transformers(
+        self: Self,
+        name: str,
+        version: str | ModelVersion,
+    ) -> list[SchemaTransformer]:
+        """Get all transformers for a model version.
+
+        Args:
+            name: Name of the model.
+            version: Model version.
+
+        Returns:
+            List of transformer functions.
+
+        Example:
+            ```python
+            transformers = manager.get_schema_transformers("User", "1.0.0")
+            print(f"Found {len(transformers)} transformers")
+            ```
+        """
+        return self._schema_manager.get_transformers(name, version)
+
+    def clear_schema_transformers(
+        self: Self,
+        name: str | None = None,
+        version: str | ModelVersion | None = None,
+    ) -> None:
+        """Clear schema transformers.
+
+        Args:
+            name: Optional model name. If None, clears all.
+            version: Optional version. If None, clears all versions of model.
+
+        Example:
+            ```python
+            # Clear all transformers
+            manager.clear_schema_transformers()
+
+            # Clear User transformers
+            manager.clear_schema_transformers("User")
+
+            # Clear specific version
+            manager.clear_schema_transformers("User", "1.0.0")
+            ```
+        """
+        self._schema_manager.clear_transformers(name, version)
+
     def get_schema(
         self: Self,
         name: str,
         version: str | ModelVersion,
+        config: SchemaConfig | None = None,
         **kwargs: Any,
     ) -> JsonSchema:
         """Get JSON schema for a specific version.
@@ -553,12 +898,27 @@ class ModelManager:
         Args:
             name: Name of the model.
             version: Semantic version.
-            **kwargs: Additional schema generation arguments.
+            config: Optional schema configuration (overrides default).
+            **kwargs: Additional schema generation arguments (e.g.,
+                mode="serialization").
 
         Returns:
             JSON schema dictionary.
+
+        Example:
+            ```python
+            # Use default config
+            schema = manager.get_schema("User", "1.0.0")
+
+            # Override with custom config
+            config = SchemaConfig(mode="serialization")
+            schema = manager.get_schema("User", "1.0.0", config=config)
+
+            # Quick override with kwargs
+            schema = manager.get_schema("User", "1.0.0", mode="serialization")
+            ```
         """
-        return self._schema_manager.get_schema(name, version, **kwargs)
+        return self._schema_manager.get_schema(name, version, config=config, **kwargs)
 
     def list_models(self: Self) -> list[str]:
         """Get list of all registered models.
@@ -585,6 +945,7 @@ class ModelManager:
         indent: int = 2,
         separate_definitions: bool = False,
         ref_template: str | None = None,
+        config: SchemaConfig | None = None,
     ) -> None:
         """Export all schemas to JSON files.
 
@@ -592,27 +953,32 @@ class ModelManager:
             output_dir: Directory path for output.
             indent: JSON indentation level.
             separate_definitions: If True, create separate schema files for nested
-                models and use $ref to reference them. Only applies to models with
-                'enable_ref=True'.
+                models and use $ref to reference them.
             ref_template: Template for $ref URLs when separate_definitions=True.
-                Defaults to relative file references if not provided.
+            config: Optional schema configuration for all exported schemas.
 
         Example:
-            >>> # Inline definitions (default)
-            >>> manager.dump_schemas("schemas/")
-            >>>
-            >>> # Separate sub-schemas with relative refs
-            >>> manager.dump_schemas("schemas/", separate_definitions=True)
-            >>>
-            >>> # Separate sub-schemas with absolute URLs
-            >>> manager.dump_schemas(
-            ...     "schemas/",
-            ...     separate_definitions=True,
-            ...     ref_template="https://example.com/schemas/{model}_v{version}.json"
-            ... )
+            ```python
+            # Export with custom generator
+            config = SchemaConfig(
+                schema_generator=CustomGenerator,
+                mode="validation"
+            )
+            manager.dump_schemas("schemas/", config=config)
+
+            # Export validation and serialization schemas separately
+            manager.dump_schemas(
+                "schemas/validation/",
+                config=SchemaConfig(mode="validation")
+            )
+            manager.dump_schemas(
+                "schemas/serialization/",
+                config=SchemaConfig(mode="serialization")
+            )
+            ```
         """
         self._schema_manager.dump_schemas(
-            output_dir, indent, separate_definitions, ref_template
+            output_dir, indent, separate_definitions, ref_template, config=config
         )
 
     def get_nested_models(
@@ -640,54 +1006,15 @@ class ModelManager:
     ) -> MigrationTestResults:
         """Test a migration with multiple test cases.
 
-        Executes a migration on multiple test inputs and validates the outputs match
-        expected values. Useful for regression testing and validating migration logic.
-
         Args:
             name: Name of the model.
             from_version: Source version to migrate from.
             to_version: Target version to migrate to.
-            test_cases: List of test cases, either as (source, target) tuples or
-                MigrationTestCase objects. If target is None, only verifies the
-                migration completes without errors.
+            test_cases: List of test cases.
 
         Returns:
             MigrationTestResults containing individual results for each test case.
-
-        Example:
-            >>> # Using tuples (source, target)
-            >>> results = manager.test_migration(
-            ...     "User", "1.0.0", "2.0.0",
-            ...     test_cases=[
-            ...         ({"name": "Alice"}, {"name": "Alice", "email": "alice@example.com"}),
-            ...         ({"name": "Bob"}, {"name": "Bob", "email": "bob@example.com"})
-            ...     ]
-            ... )
-            >>> assert results.all_passed
-            >>>
-            >>> # Using MigrationTestCase objects
-            >>> results = manager.test_migration(
-            ...     "User", "1.0.0", "2.0.0",
-            ...     test_cases=[
-            ...         MigrationTestCase(
-            ...             source={"name": "Alice"},
-            ...             target={"name": "Alice", "email": "alice@example.com"},
-            ...             description="Standard user migration"
-            ...         )
-            ...     ]
-            ... )
-            >>>
-            >>> # Use in pytest
-            >>> def test_user_migration():
-            ...     results = manager.test_migration("User", "1.0.0", "2.0.0", test_cases)
-            ...     results.assert_all_passed()  # Raises AssertionError with details if failed
-            >>>
-            >>> # Inspect failures
-            >>> if not results.all_passed:
-            ...     for failure in results.failures:
-            ...         print(f"Failed: {failure.test_case.description}")
-            ...         print(f"  Error: {failure.error}")
-        """  # noqa: E501
+        """
         results = []
 
         for test_case_input in test_cases:
